from enum import Enum


class Currency(Enum):
    """Currencies as for ISO 4217."""
    AFN = 1
    ARS = 2
    AWG = 3
    AUD = 4
    AZN = 5
    BSD = 6
    BBD = 7
    BDT = 8
    BYR = 9
    BZD = 10
    BMD = 11
    BOB = 12
    BAM = 13
    BWP = 14
    BGN = 15
    BRL = 16
    BND = 17
    KHR = 18
    CAD = 19
    KYD = 20
    CLP = 21
    CNY = 22
    COP = 23
    CRC = 24
    HRK = 25
    CUP = 26
    CZK = 27
    DKK = 28
    DOP = 29
    XCD = 30
    EGP = 31
    SVC = 32
    EEK = 33
    EUR = 34
    FKP = 35
    FJD = 36
    GHC = 37
    GIP = 38
    GTQ = 39
    GGP = 40
    GYD = 41
    HNL = 42
    HKD = 43
    HUF = 44
    ISK = 45
    INR = 46
    IDR = 47
    IRR = 48
    IMP = 49
    ILS = 50
    JMD = 51
    JPY = 52
    JEP = 53
    KZT = 54
    KPW = 55
    KRW = 56
    KGS = 57
    LAK = 58
    LVL = 59
    LBP = 60
    LRD = 61
    LTL = 62
    MKD = 63
    MYR = 64
    MUR = 65
    MXN = 66
    MNT = 67
    MZN = 68
    NAD = 69
    NPR = 70
    ANG = 71
    NZD = 72
    NIO = 73
    NGN = 74
    NOK = 75
    OMR = 76
    PKR = 77
    PAB = 78
    PYG = 79
    PEN = 80
    PHP = 81
    PLN = 82
    QAR = 83
    RON = 84
    RUB = 85
    SHP = 86
    SAR = 87
    RSD = 88
    SCR = 89
    SGD = 90
    SBD = 91
    SOS = 92
    ZAR = 93
    LKR = 94
    SEK = 95
    CHF = 96
    SRD = 97
    SYP = 98
    TWD = 99
    THB = 100
    TTD = 101
    TRY = 102
    TRL = 103
    TVD = 104
    UAH = 105
    GBP = 106
    USD = 107
    UYU = 108
    UZS = 109
    VEF = 110
    VND = 111
    YER = 112
    ZWD = 113

    @property
    def symbol(self) -> str:
        try:
            return Symbol[self.name].value
        except KeyError:
            return self.name

    def __format__(self, format_spec):
        if 's' in format_spec:
            return format(self.symbol)
        return super().__format__(format_spec)


class Symbol(Enum):
    """Currencies with their symbols."""
    AFN = '؋'
    ARS = '$'
    AWG = ' ƒ'
    AUD = '$'
    AZN = '₼'
    BSD = '$'
    BBD = '$'
    BYN = ' Br'
    BZD = ' BZ$'
    BMD = '$'
    BOB = '$b'
    BAM = ' KM'
    BWP = ' P'
    BGN = ' лв'
    BRL = ' R$'
    BND = '$'
    KHR = '៛'
    CAD = '$'
    KYD = '$'
    CLP = '$'
    CNY = '¥'
    COP = '$'
    CRC = '₡'
    HRK = ' kn'
    CUP = '₱'
    CZK = ' Kč'
    DKK = ' kr'
    DOP = ' RD$'
    XCD = '$'
    EGP = '£'
    SVC = '$'
    EUR = '€'
    FKP = '£'
    FJD = '$'
    GHS = '¢'
    GIP = '£'
    GTQ = ' Q'
    GGP = '£'
    GYD = '$'
    HNL = ' L'
    HKD = '$'
    HUF = ' Ft'
    ISK = ' kr'
    IDR = ' Rp'
    IRR = '﷼'
    IMP = '£'
    ILS = '₪'
    JMD = ' J$'
    JPY = '¥'
    JEP = '£'
    KZT = ' лв'
    KPW = '₩'
    KRW = '₩'
    KGS = ' лв'
    LAK = '₭'
    LBP = '£'
    LRD = '$'
    MKD = ' ден'
    MYR = ' RM'
    MUR = '₨'
    MXN = '$'
    MNT = '₮'
    MZN = ' MT'
    NAD = '$'
    NPR = '₨'
    ANG = ' ƒ'
    NZD = '$'
    NIO = ' C$'
    NGN = '₦'
    NOK = ' kr'
    OMR = '﷼'
    PKR = '₨'
    PAB = ' B /.'
    PYG = ' Gs'
    PEN = ' S /.'
    PHP = '₱'
    PLN = ' zł'
    QAR = '﷼'
    RON = ' lei'
    RUB = '₽'
    SHP = '£'
    SAR = '﷼'
    RSD = ' Дин.'
    SCR = '₨'
    SGD = '$'
    SBD = '$'
    SOS = ' S'
    ZAR = ' R'
    LKR = '₨'
    SEK = ' kr'
    CHF = ' CHF'
    SRD = '$'
    SYP = '£'
    TWD = ' NT$'
    THB = '฿'
    TTD = ' TT$'
    TVD = '$'
    UAH = '₴'
    GBP = '£'
    USD = '$'
    UYU = '$U'
    UZS = ' лв'
    VEF = ' Bs'
    VND = '₫'
    YER = '﷼'
    ZWD = ' Z$'
